==> WebScripts-2.4.5.tar.gz: WebScripts-2.4.5/WebScripts/scripts/uploads/delete_file.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

###################
#    This file deletes an uploaded file on a WebScripts Server
#    Copyright (C) 2021  Maurice Lambert

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
###################

"""This tools run scripts and display the result in a Web Interface.

This file deletes an uploaded file on a WebScripts Server."""

__version__ = "0.0.1"
__author__ = "Maurice Lambert"
__author_email__ = "mauricelambert434@gmail.com"
__maintainer__ = "Maurice Lambert"
__maintainer_email__ = "mauricelambert434@gmail.com"
__description__ = """
This tools run scripts and display the result in a Web Interface.

This file deletes an uploaded file on a WebScripts Server"""
__license__ = "GPL-3.0 License"
__url__ = "https://github.com/mauricelambert/WebScripts"

copyright = """
WebScripts  Copyright (C) 2021  Maurice Lambert
This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions.
"""
license = __license__
__copyright__ = copyright

__all__ = []

from modules.uploads_management import delete_file
import sys


def main() -> None:

    """This function uploads a file on a WebScripts Server."""

    if len(sys.argv) != 2:
        print("USAGE: delete_file.py [FILENAME required string]")
        sys.exit(1)

    filename = sys.argv[1]

    try:
        upload = delete_file(filename)
    except Exception as e:
        print(f"{e.__class__.__name__}: {e}")
        sys.exit(127)

    print(f"Deleted file:\n\t - Name: {upload.name}")


if __name__ == "__main__":
    main()
    sys.exit(0)

==> WebScripts-2.4.14.tar.gz: WebScripts-2.4.14/WebScripts/scripts/uploads/delete_file.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

###################
#    This file deletes an uploaded file on a WebScripts Server
#    Copyright (C) 2021  Maurice Lambert

#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.

#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.

#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
###################

"""This tool run scripts and display the result in a Web Interface.

This file deletes an uploaded file on a WebScripts Server."""

__version__ = "0.0.1"
__author__ = "Maurice Lambert"
__author_email__ = "mauricelambert434@gmail.com"
__maintainer__ = "Maurice Lambert"
__maintainer_email__ = "mauricelambert434@gmail.com"
__description__ = """
This tool run scripts and display the result in a Web Interface.

This file deletes an uploaded file on a WebScripts Server"""
__license__ = "GPL-3.0 License"
__url__ = "https://github.com/mauricelambert/WebScripts"

copyright = """
WebScripts  Copyright (C) 2021  Maurice Lambert
This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions.
"""
license = __license__
__copyright__ = copyright

__all__ = []

from modules.uploads_management import delete_file
import sys


def main() -> None:

    """This function uploads a file on a WebScripts Server."""

    if len(sys.argv) != 2:
        print("USAGE: delete_file.py [FILENAME required string]")
        sys.exit(1)

    filename = sys.argv[1]

    try:
        upload = delete_file(filename)
    except Exception as e:
        print(f"{e.__class__.__name__}: {e}")
        sys.exit(127)

    print(f"Deleted file:\n\t - Name: {upload.name}")


if __name__ == "__main__":
    main()
    sys.exit(0)
